@@ -1,29 +1,37 @@
+# pylint: disable=no-member
 import re
 from abc import abstractmethod
 from enum import Enum
-from typing import List, Set, Dict, Optional
-from cloudrail.knowledge.context.terraform_state import TerraformState
+from typing import List, Set, Optional, FrozenSet
+
+from cloudrail.knowledge.context.iac_state import IacState
+from cloudrail.knowledge.context.iac_type import IacType
+from cloudrail.knowledge.exceptions import UnsupportedIacTypeException
 
 
-class EntityOrigin(Enum):
+class EntityOrigin(str, Enum):
     LIVE_ENV = 'live_environment'
     TERRAFORM = 'terraform'
     PSEUDO = 'pseudo'
+    CLOUDFORMATION = 'cloudformation'
 
 
 class Mergeable:
 
     def __init__(self):
-        self.aliases: Set[str] = set()
-        self.terraform_state: Optional[TerraformState] = None
+        self._aliases: Set[str] = set()
+        self.iac_state: Optional[IacState] = None
         self.is_pseudo = False
-        self.tags: Dict[str, str] = {}
-        self.invalidation: List[str] = []
+        self.invalidation: Set[str] = set()
 
     def with_aliases(self, *aliases: str):
-        self.aliases.update(aliases)
+        self._aliases.update(filter(None, aliases))
         return self
 
+    @property
+    def aliases(self) -> FrozenSet[str]:
+        return frozenset(self._aliases)
+
     @abstractmethod
     def get_keys(self) -> List[str]:
         pass
@@ -36,14 +44,18 @@ class Mergeable:
         else:
             return ' '.join(words) + 's'
 
-    def get_name(self) -> str:
-        pass
+    def get_name(self) -> Optional[str]:
+        if hasattr(self, 'name'):
+            return self.name
+        return None
 
     def get_id(self) -> str:
         pass
 
-    def get_arn(self) -> str:
-        pass
+    def get_arn(self) -> Optional[str]:
+        if hasattr(self, 'arn'):
+            return self.arn
+        return None
 
     def get_extra_data(self) -> str:
         pass
@@ -53,15 +65,20 @@ class Mergeable:
         pass
 
     def is_new_resource(self) -> bool:
-        return self.terraform_state is not None and self.terraform_state.is_new
+        return self.iac_state is not None and self.iac_state.is_new
 
     def get_existing_cloud_resource_url(self) -> Optional[str]:
         if not self.is_new_resource():
             return self.get_cloud_resource_url()
         return None
 
+    def get_existing_cloud_entity_id(self) -> Optional[str]:
+        if not self.is_new_resource():
+            return self.get_id()
+        return None
+
     def add_invalidation(self, reason: str) -> None:
-        self.invalidation.append(reason)
+        self.invalidation.add(reason)
 
     @property
     def is_invalidated(self) -> bool:
@@ -75,14 +92,19 @@ class Mergeable:
     def origin(self) -> EntityOrigin:
         if self.is_pseudo:
             return EntityOrigin.PSEUDO
-        elif self.terraform_state:
-            return EntityOrigin.TERRAFORM
+        elif self.iac_state:
+            if self.iac_state.iac_type == IacType.TERRAFORM:
+                return EntityOrigin.TERRAFORM
+            elif self.iac_state.iac_type == IacType.CLOUDFORMATION:
+                return EntityOrigin.CLOUDFORMATION
+            else:
+                raise UnsupportedIacTypeException()
         else:
             return EntityOrigin.LIVE_ENV
 
     @property
     def is_managed_by_iac(self) -> bool:
-        return self.origin == EntityOrigin.TERRAFORM
+        return bool(self.iac_state)
 
     @property
     @abstractmethod
@@ -101,3 +123,11 @@ class Mergeable:
         A list of manual reasons why this resource should be invalidated
         """
         return []
+
+    @staticmethod
+    def is_standalone() -> bool:
+        return True
+
+    @abstractmethod
+    def to_drift_detection_object(self) -> dict:
+        pass
