@@ -1,8 +1,8 @@
 from typing import List, Dict, Optional
 
-from cloudrail.knowledge.context.aws.indirect_public_connection_data import IndirectPublicConnectionData
+from cloudrail.knowledge.context.aws.resources.indirect_public_connection_data import IndirectPublicConnectionData
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
 
@@ -12,7 +12,7 @@ class IndirectPublicAccessDbRds(AwsBaseRule):
     def get_id(self) -> str:
         return 'indirect_public_access_db_rds'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
 
         for rds_cluster in env_context.rds_clusters:
@@ -61,5 +61,5 @@ class IndirectPublicAccessDbRds(AwsBaseRule):
                     violation_info.security_group))
         return issues
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.rds_clusters or environment_context.rds_instances)
