@@ -1,8 +1,8 @@
 from typing import List, Dict, Optional
 
-from cloudrail.knowledge.context.aws.indirect_public_connection_data import IndirectPublicConnectionData
+from cloudrail.knowledge.context.aws.resources.indirect_public_connection_data import IndirectPublicConnectionData
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
 
@@ -12,7 +12,7 @@ class IndirectPublicAccessElasticSearchRule(AwsBaseRule):
     def get_id(self) -> str:
         return 'indirect_public_access_elastic_search_rule'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
         for es_domain in [es for es in env_context.elastic_search_domains if es.is_in_vpc]:
             violation_data: Optional[IndirectPublicConnectionData] = es_domain.indirect_public_connection_data
@@ -39,5 +39,5 @@ class IndirectPublicAccessElasticSearchRule(AwsBaseRule):
                         , es_domain, violation_data.security_group))
         return issues
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.elastic_search_domains)
