@@ -3,13 +3,13 @@ from typing import List, Dict
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 
 
 class S3AclAllowPublicAccessRule(AwsBaseRule):
     # Notice:
     # - this rule don't issue on violation on the bucket object level
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues_list: List[Issue] = []
         for bucket in env_context.s3_buckets:
             for resource in bucket.publicly_allowing_resources:
@@ -21,5 +21,5 @@ class S3AclAllowPublicAccessRule(AwsBaseRule):
     def get_id(self) -> str:
         return "s3_acl_disallow_public_and_cross_account"
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.s3_buckets)
