@@ -1,7 +1,7 @@
 from typing import List, Dict
-from cloudrail.knowledge.context.aws.kms.kms_key_manager import KeyManager
+from cloudrail.knowledge.context.aws.resources.kms.kms_key_manager import KeyManager
 
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
@@ -12,7 +12,7 @@ class EnsureNeptuneClusterEncryptedAtRestWithCustomerManagedCmkRule(AwsBaseRule)
     def get_id(self) -> str:
         return 'non_car_neptune_cluster_encrypt_at_rest_with_customer_managed_cmk'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
 
         for neptune_cluster in env_context.neptune_clusters:
@@ -24,5 +24,5 @@ class EnsureNeptuneClusterEncryptedAtRestWithCustomerManagedCmkRule(AwsBaseRule)
                             f'is not set to be encrypted at rest using customer-managed CMK', neptune_cluster, neptune_cluster))
         return issues
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.neptune_clusters)
