@@ -1,6 +1,6 @@
 from typing import List, Dict
 
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
@@ -11,7 +11,7 @@ class EnsureRedshiftClusterCreatedEncryptedRule(AwsBaseRule):
     def get_id(self) -> str:
         return 'non_car_redshift_cluster_encrypt_at_rest_creating'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
 
         for redshift_cluster in env_context.redshift_clusters:
@@ -23,5 +23,5 @@ class EnsureRedshiftClusterCreatedEncryptedRule(AwsBaseRule):
                             f'set to use encryption at rest', redshift_cluster, redshift_cluster))
         return issues
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.redshift_clusters)
