@@ -1,7 +1,7 @@
 from typing import List, Dict
 
-from cloudrail.knowledge.context.aws.ecs.ecs_task_definition import EfsVolume
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.resources.ecs.ecs_task_definition import EfsVolume
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
@@ -12,7 +12,7 @@ class EnsureEcsTaskDefinitionCreatedWithEfsEncryptInTransitRule(AwsBaseRule):
     def get_id(self) -> str:
         return 'non_car_ecs_task_definition_encrypt_in_transit_with_EFS'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
 
         for task_def in env_context.ecs_task_definitions:
@@ -33,5 +33,5 @@ class EnsureEcsTaskDefinitionCreatedWithEfsEncryptInTransitRule(AwsBaseRule):
                 volumes_list.append(volume)
         return volumes_list
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.ecs_task_definitions)
