@@ -2,8 +2,8 @@ import os
 from dataclasses import dataclass, field
 from enum import Enum
 from typing import Optional, Set, Dict
-
 import yaml
+from cloudrail.knowledge.context.iac_type import IacType
 from cloudrail.knowledge.context.cloud_provider import CloudProvider
 
 
@@ -37,6 +37,7 @@ class SecurityLayer(str, Enum):
     DISASTER_RECOVERY = 'disaster_recovery'
     STORAGE = 'storage'
     TAGGING = 'tagging'
+    RUNTIME = 'runtime'
 
 
 class ResourceType(str, Enum):
@@ -49,7 +50,6 @@ class ResourceType(str, Enum):
     KEY_MGMT = 'key_mgmt'
     NETWORK = 'network'
     DATABASE = 'database'
-    CLOUDFRONT = 'cloudfront'
     CONTENT_DELIVERY = 'content_delivery'
     SERVICE_ENDPOINT = 'service_endpoint'
     CODE = 'code'
@@ -83,6 +83,7 @@ class RuleMetadata:
     rule_type: RuleType
     security_layer: SecurityLayer
     resource_types: Set[ResourceType]
+    supported_iac_types: Set[IacType]
     cloud_provider: CloudProvider = field(default=CloudProvider.AMAZON_WEB_SERVICES)
     is_deleted: bool = False
     compliance: Dict[BenchmarkType, Dict[str, str]] = field(default_factory=dict)
